########################################################################
# ExSSO: (Ex)haustive (S)earch for (S)ymmetric (O)ligomer              #
#                                                                      #
# configure.py: set parameters of ExSSO                                #
#                                                                      #
# Usage: python configure.py                                           #
#                                                                      #
# Contact: james_chou@hms.harvard.edu                                  #
########################################################################

import os
import sys

########################Input parameter setting#########################

# Protein name
proteinName = 'HIVtmd'

# Home directory of ExSSO
homeDir = '/home/user/ExSSO'

# Protomer structure
pdbFile = '/home/user/ExSSO/example/HIV/protomer.pdb'

# Inter-protomer NOE restraints
noeFile = '/home/user/ExSSO/example/HIV/restraints.noe'

# Membrane restraints (optional)
memFile = '/home/user/ExSSO/example/HIV/restraints.mem'

# Number of protomers
numProtomer = 3

# Use membrane restraint, 1 for "yes" and 0 for "no"
memResFlag = 0

###########################Search parameters############################

# Step size for Euler angles
ss_angle = 5

# Distance between Z-axis (the symmetry axis) and center-of-mass
# Begin with 3.0
r_beg = 3.0
# End up with 15.0
r_end = 15.0

# Step size for distance r
ss_r = 0.5

# The average restraint uncertainty used for the ACCEPT criterion
uncertainty = 1.5

#############################End of setting#############################

######################Don't change anything below#######################

if not isinstance(proteinName, str) or len(proteinName) <= 0:
    print '[Error] Protein name should be specified'
    sys.exit(1)
if not os.path.exists(homeDir):
    print '[Error] \'' + homeDir + '\'' + ' does not exist'
    sys.exit(1)
if not os.path.exists(pdbFile):
    print '[Error] \'' + pdbFile + '\'' + ' does not exist'
    sys.exit(1)
if not os.path.exists(noeFile):
    print '[Error] \'' + noeFile + '\'' + ' does not exist'
    sys.exit(1)
if not isinstance(numProtomer, int) or numProtomer <= 1:
    print '[Error] The number of protomers should be more than 1'
    sys.exit(1)
if memResFlag == 1:
    if not os.path.exists(memFile):
        print '[Error] \'' + memFile + '\'' + ' does not exist'
        sys.exit(1)

# Write parameters into file
workDir = homeDir + '/' + proteinName
if not os.path.exists(workDir):
    os.mkdir(workDir)
fp = open(workDir + '/param', 'w')
print 'proteinName=' + proteinName
fp.write('proteinName=' + proteinName + '\n')
print 'homeDir=' + homeDir
fp.write('homeDir=' + homeDir + '\n')
print 'workDir=' + workDir
fp.write('workDir=' + workDir + '\n')
print 'pdbFile=' + pdbFile
fp.write('pdbFile=' + pdbFile + '\n')
print 'noeFile=' + noeFile
fp.write('noeFile=' + noeFile + '\n')
if memResFlag == 1:
    print 'memFile=' + memFile
    fp.write('memFile=' + memFile + '\n')
print 'numProtomer=' + str(numProtomer)
fp.write('numProtomer=' + str(numProtomer) + '\n')
print 'memResFlag=' + str(memResFlag)
fp.write('memResFlag=' + str(memResFlag) + '\n')
print 'ss_angle=' + str(ss_angle)
fp.write('ss_angle=' + str(ss_angle) + '\n')
print 'r_beg=' + str(r_beg)
fp.write('r_beg=' + str(r_beg) + '\n')
print 'r_end=' + str(r_end)
fp.write('r_end=' + str(r_end) + '\n')
print 'ss_r=' + str(ss_r)
fp.write('ss_r=' + str(ss_r) + '\n')
print 'uncertainty=' + str(uncertainty)
fp.write('uncertainty=' + str(uncertainty) + '\n')
fp.close()
print '[Done] \'param\' can be found in \'' + workDir + '\''
